@@ -36,7 +36,7 @@
  *
  * ***** END LICENSE BLOCK *****
  *
- * $Id: EphyHeaderSniffer.cpp 8323 2008-06-30 18:22:04Z chpe $
+ * $Id$
  */
 
 #include "mozilla-config.h"
@@ -414,8 +414,12 @@ nsresult EphyHeaderSniffer::PerformSave (nsIURI* inOriginalURI)
 						EPHY_FILE_FILTER_ALL_SUPPORTED);
 		gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (dialog), TRUE);
 
+		/* Remove leading dots */
+		char *fname = filename;
+		while (*fname == '.') fname++;
+
 		gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dialog),
-                                                   filename);
+                                                   fname);
 
 		g_signal_connect (dialog, "response",
 				  G_CALLBACK (filechooser_response_cb), this);
