@@ -50,18 +50,12 @@
 #include "ephy-link.h"
 #include "ephy-stock-icons.h"
 #include "ephy-string.h"
-#include "eel-app-launch-context.h"
 #include "pdm-dialog.h"
 
 #include <string.h>
 #include <glib.h>
 #include <gio/gio.h>
-#include <gtk/gtkaboutdialog.h>
-#include <gtk/gtkeditable.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtkicontheme.h>
-#include <gtk/gtktoggleaction.h>
-#include <gtk/gtkprintoperation.h>
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 
 static void
